==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/2a/2a1e3dfe802ce4839e850d241cc115d6.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/MessengerBundle/Retry/RetryStrategy.php */
class __TwigTemplate_37a6eb38b2161a63d59351bd234e661f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\MessengerBundle\\Retry;

use Mautic\\CoreBundle\\Helper\\CoreParametersHelper;
use Symfony\\Component\\Messenger\\Envelope;
use Symfony\\Component\\Messenger\\Retry\\MultiplierRetryStrategy;
use Symfony\\Component\\Messenger\\Retry\\RetryStrategyInterface;

class RetryStrategy implements RetryStrategyInterface
{
    private RetryStrategyInterface \$retryStrategy;

    public function __construct(
        private CoreParametersHelper \$parametersHelper
    ) {
    }

    public function isRetryable(Envelope \$message): bool
    {
        return \$this->getRetryStrategy()->isRetryable(\$message);
    }

    public function getWaitingTime(Envelope \$message): int
    {
        return \$this->getRetryStrategy()->getWaitingTime(\$message);
    }

    private function getRetryStrategy(): RetryStrategyInterface
    {
        if (!isset(\$this->retryStrategy)) {
            \$this->retryStrategy = new MultiplierRetryStrategy(
                (int) \$this->parametersHelper->get('messenger_retry_strategy_max_retries'),
                (int) \$this->parametersHelper->get('messenger_retry_strategy_delay'),
                (float) \$this->parametersHelper->get('messenger_retry_strategy_multiplier'),
                (int) \$this->parametersHelper->get('messenger_retry_strategy_max_delay'),
            );
        }

        return \$this->retryStrategy;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/MessengerBundle/Retry/RetryStrategy.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/MessengerBundle/Retry/RetryStrategy.php", "/var/www/html/mauticGIT-Test/app/bundles/MessengerBundle/Retry/RetryStrategy.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/2a/2a1e3dfe802ce4839e850d241cc115d6.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/MessengerBundle/Retry/RetryStrategy.php */
class __TwigTemplate_37a6eb38b2161a63d59351bd234e661f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\MessengerBundle\\Retry;

use Mautic\\CoreBundle\\Helper\\CoreParametersHelper;
use Symfony\\Component\\Messenger\\Envelope;
use Symfony\\Component\\Messenger\\Retry\\MultiplierRetryStrategy;
use Symfony\\Component\\Messenger\\Retry\\RetryStrategyInterface;

class RetryStrategy implements RetryStrategyInterface
{
    private RetryStrategyInterface \$retryStrategy;

    public function __construct(
        private CoreParametersHelper \$parametersHelper
    ) {
    }

    public function isRetryable(Envelope \$message): bool
    {
        return \$this->getRetryStrategy()->isRetryable(\$message);
    }

    public function getWaitingTime(Envelope \$message): int
    {
        return \$this->getRetryStrategy()->getWaitingTime(\$message);
    }

    private function getRetryStrategy(): RetryStrategyInterface
    {
        if (!isset(\$this->retryStrategy)) {
            \$this->retryStrategy = new MultiplierRetryStrategy(
                (int) \$this->parametersHelper->get('messenger_retry_strategy_max_retries'),
                (int) \$this->parametersHelper->get('messenger_retry_strategy_delay'),
                (float) \$this->parametersHelper->get('messenger_retry_strategy_multiplier'),
                (int) \$this->parametersHelper->get('messenger_retry_strategy_max_delay'),
            );
        }

        return \$this->retryStrategy;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/MessengerBundle/Retry/RetryStrategy.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/MessengerBundle/Retry/RetryStrategy.php", "/var/www/html/production-demo/app/bundles/MessengerBundle/Retry/RetryStrategy.php");
    }
}
